@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.200002';
+our $VERSION = '0.200003';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -37,22 +37,20 @@ has ip_version => (
     required => 1,
 );
 
-{
-    #<<<
-    my $size_type = subtype
-        as 'Int',
-        where { ( $_ % 4 == 0 ) && $_ >= 24 && $_ <= 128 },
-        message {
-            'The record size must be a number from 24-128 that is divisible by 4';
-        };
-    #>>>
+#<<<
+my $RecordSizeType = subtype
+    as 'Int',
+    where { ( $_ % 4 == 0 ) && $_ >= 24 && $_ <= 128 },
+    message {
+        'The record size must be a number from 24-128 that is divisible by 4';
+    };
+#>>>
 
-    has record_size => (
-        is       => 'ro',
-        isa      => $size_type,
-        required => 1,
-    );
-}
+has record_size => (
+    is       => 'ro',
+    isa      => $RecordSizeType,
+    required => 1,
+);
 
 has merge_record_collisions => (
     is      => 'ro',
@@ -284,11 +282,20 @@ sub write_tree {
     );
 
     # ::/128 and ::1/128 are reserved under IPv6 but these are already covered
-    # under 0.0.0.0/8
+    # under 0.0.0.0/8. We include all of 2001::/23 except 2001::/32 as the
+    # latter is Teredo, which is globally routable.
     my @reserved_6 = (
         @reserved_4, qw(
             100::/64
-            2001::/23
+            2001:1::/32
+            2001:2::/31
+            2001:4::/30
+            2001:8::/29
+            2001:10::/28
+            2001:20::/27
+            2001:40::/26
+            2001:80::/25
+            2001:100::/24
             2001:db8::/32
             fc00::/7
             fe80::/10
@@ -381,14 +388,18 @@ sub write_tree {
 
 sub new_from_frozen_tree {
     my $class = shift;
-    my ( $filename, $callback, $database_type, $description, $merge_strategy )
+    my (
+        $filename, $callback, $database_type, $description, $merge_strategy,
+        $record_size
+        )
         = validated_list(
         \@_,
         filename              => { isa => 'Str' },
         map_key_type_callback => { isa => 'CodeRef' },
         database_type         => { isa => 'Str', optional => 1 },
         description           => { isa => 'HashRef[Str]', optional => 1 },
-        merge_strategy        => { isa => $MergeStrategyEnum, optional => 1 }
+        merge_strategy        => { isa => $MergeStrategyEnum, optional => 1 },
+        record_size           => { isa => $RecordSizeType, optional => 1 },
         );
 
     open my $fh, '<:raw', $filename;
@@ -406,6 +417,7 @@ sub new_from_frozen_tree {
 
     $params->{database_type} = $database_type if defined $database_type;
     $params->{description}   = $description   if defined $description;
+    $params->{record_size}   = $record_size   if defined $record_size;
 
     if ( defined $merge_strategy ) {
         $params->{merge_strategy} = $merge_strategy;
@@ -462,7 +474,7 @@ MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory -
 
 =head1 VERSION
 
-version 0.200002
+version 0.200003
 
 =head1 SYNOPSIS
 
@@ -683,8 +695,9 @@ This parameter is optional. It defaults to false.
 =item * remove_reserved_networks
 
 If this is true, reserved networks will be removed from the database by
-C<write_tree()> before the tree is written to the file handle. The default is
-true.
+C<write_tree()> before the tree is written to the file handle. Reserved
+networks that are globally routable to an individual device, such as Teredo,
+are I<not> removed. The default is true.
 
 =back
 
